@@ -34,7 +34,6 @@
 
 #include "xf86.h"
 #include "xf86_OSproc.h"
-#include "xf86_ansic.h"
 #include "xf86Priv.h"
 
 #include "xf86PciInfo.h"
@@ -47,8 +46,7 @@
 
 #include "miline.h"
 
-
-
+#include <errno.h>
 
 #include <inttypes.h>
 #include "mga_reg.h"
@@ -80,25 +78,9 @@ static char MGAClientDriverName[] = "mga";
 
 /* DRI buffer management
  */
-extern void Mga8DRIInitBuffers( WindowPtr pWin, RegionPtr prgn,
-				CARD32 index );
-extern void Mga8DRIMoveBuffers( WindowPtr pParent, DDXPointRec ptOldOrg,
-				RegionPtr prgnSrc, CARD32 index );
-
-extern void Mga16DRIInitBuffers( WindowPtr pWin, RegionPtr prgn,
-				 CARD32 index );
-extern void Mga16DRIMoveBuffers( WindowPtr pParent, DDXPointRec ptOldOrg,
-				 RegionPtr prgnSrc, CARD32 index );
-
-extern void Mga24DRIInitBuffers( WindowPtr pWin, RegionPtr prgn,
-				 CARD32 index );
-extern void Mga24DRIMoveBuffers( WindowPtr pParent, DDXPointRec ptOldOrg,
-				 RegionPtr prgnSrc, CARD32 index );
-
-extern void Mga32DRIInitBuffers( WindowPtr pWin, RegionPtr prgn,
-				 CARD32 index );
-extern void Mga32DRIMoveBuffers( WindowPtr pParent, DDXPointRec ptOldOrg,
-				 RegionPtr prgnSrc, CARD32 index );
+extern void mgaDRIInitBuffers( WindowPtr pWin, RegionPtr prgn, CARD32 index );
+extern void mgaDRIMoveBuffers( WindowPtr pParent, DDXPointRec ptOldOrg,
+    RegionPtr prgnSrc, CARD32 index );
 
 
 /* Initialize the visual configs that are supported by the hardware.
@@ -150,7 +132,6 @@ static Bool MGAInitVisualConfigs( ScreenPtr pScreen )
       }
 
       i = 0;
-      depth = 1;
       for ( accum = 0 ; accum <= 1 ; accum++ ) {
          for ( stencil = 0 ; stencil <= 1 ; stencil++ ) {
             for ( db = 1 ; db >= 0 ; db-- ) {
@@ -183,11 +164,7 @@ static Bool MGAInitVisualConfigs( ScreenPtr pScreen )
 	       }
                pConfigs[i].stereo		= FALSE;
                pConfigs[i].bufferSize		= 16;
-               if ( depth ) {
-                  pConfigs[i].depthSize		= 16;
-               } else {
-                  pConfigs[i].depthSize		= 0;
-	       }
+               pConfigs[i].depthSize		= 16;
                if ( stencil ) {
                   pConfigs[i].stencilSize	= 8;
                } else {
@@ -386,7 +363,6 @@ void MGAGetQuiescence( ScrnInfoPtr pScrn )
 {
    MGAPtr pMga = MGAPTR(pScrn);
 
-   DRILock( screenInfo.screens[pScrn->scrnIndex], 0 );
    pMga->haveQuiescense = 1;
 
    if ( pMga->directRenderingEnabled ) {
@@ -424,8 +400,6 @@ void MGAGetQuiescenceShared( ScrnInfoPtr pScrn )
    MGAEntPtr pMGAEnt = pMga->entityPrivate;
    MGAPtr pMGA2 = MGAPTR(pMGAEnt->pScrn_2);
 
-   DRILock( screenInfo.screens[pMGAEnt->pScrn_1->scrnIndex], 0 );
-
    pMga = MGAPTR(pMGAEnt->pScrn_1);
    pMga->haveQuiescense = 1;
    pMGA2->haveQuiescense = 1;
@@ -465,7 +439,11 @@ static void MGASwapContextShared( ScreenPtr pScreen )
    pMGA2->AccelInfoRec->NeedToSync = TRUE;
 }
 
-/* This is really only called from validate/postvalidate as we
+/* FIXME: This comment is out of date, since we aren't overriding
+ * Block/Wakeuphandler anymore.
+ *
+ *
+ * This is really only called from validate/postvalidate as we
  * override the dri lock/unlock.  Want to remove validate/postvalidate
  * processing, but need to remove all client-side use of drawable lock
  * first (otherwise there is noone recover when a client dies holding
@@ -487,14 +465,12 @@ MGADRISwapContext( ScreenPtr pScreen, DRISyncType syncType,
 		   DRIContextType oldContextType, void *oldContext,
 		   DRIContextType newContextType, void *newContext )
 {
-#if 0
    if ( syncType == DRI_3D_SYNC &&
 	oldContextType == DRI_2D_CONTEXT &&
 	newContextType == DRI_2D_CONTEXT )
    {
       MGASwapContext( pScreen );
    }
-#endif
 }
 
 static void
@@ -502,58 +478,12 @@ MGADRISwapContextShared( ScreenPtr pScreen, DRISyncType syncType,
 			  DRIContextType oldContextType, void *oldContext,
 			  DRIContextType newContextType, void *newContext )
 {
-#if 0
    if ( syncType == DRI_3D_SYNC &&
 	oldContextType == DRI_2D_CONTEXT &&
 	newContextType == DRI_2D_CONTEXT )
    {
       MGASwapContextShared( pScreen );
    }
-#endif
-}
-
-
-static void MGAWakeupHandler( int screenNum, pointer wakeupData,
-			      unsigned long result, pointer pReadmask )
-{
-    ScreenPtr pScreen = screenInfo.screens[screenNum];
-    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
-    MGAPtr pMga = MGAPTR(pScrn);
-
-    if ( xf86IsEntityShared( pScrn->entityList[0] ) 
-		&& pMga->DualHeadEnabled) {
-        MGASwapContextShared( pScreen );
-    } else {
-        MGASwapContext( pScreen );
-    }
-}
-
-static void MGABlockHandler( int screenNum, pointer blockData,
-			     pointer pTimeout, pointer pReadmask )
-
-{
-   ScreenPtr pScreen = screenInfo.screens[screenNum];
-   ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
-   MGAPtr pMga = MGAPTR(pScrn);
-   MGAEntPtr pMGAEnt;
-
-   if ( pMga->haveQuiescense ) {
-      if ( xf86IsEntityShared( pScrn->entityList[0] ) ) {
-	 /* Restore to first screen */
-	 pMga->RestoreAccelState( pScrn );
-	 xf86SetLastScrnFlag( pScrn->entityList[0], pScrn->scrnIndex );
-	 pMGAEnt = pMga->entityPrivate;
-
-	 if ( pMGAEnt->directRenderingEnabled ) {
-	    DRIUnlock( screenInfo.screens[pMGAEnt->pScrn_1->scrnIndex] );
-	 }
-      } else {
-	 if ( pMga->directRenderingEnabled ) {
-	    DRIUnlock( pScreen );
-	 }
-      }
-      pMga->haveQuiescense = 0;
-   }
 }
 
 void MGASelectBuffer( ScrnInfoPtr pScrn, int which )
@@ -993,7 +923,6 @@ Bool MGADRIScreenInit( ScreenPtr pScreen )
     * for canonical symbols in each module.
     */
    if ( !xf86LoaderCheckSymbol( "GlxSetVisualConfigs" ) )	return FALSE;
-   if ( !xf86LoaderCheckSymbol( "DRIScreenInit" ) )		return FALSE;
    if ( !xf86LoaderCheckSymbol( "drmAvailable" ) )		return FALSE;
    if ( !xf86LoaderCheckSymbol( "DRIQueryVersion" ) ) {
       xf86DrvMsg( pScreen->myNum, X_ERROR,
@@ -1049,13 +978,11 @@ Bool MGADRIScreenInit( ScreenPtr pScreen )
    pDRIInfo->ddxDriverMajorVersion = MGA_MAJOR_VERSION;
    pDRIInfo->ddxDriverMinorVersion = MGA_MINOR_VERSION;
    pDRIInfo->ddxDriverPatchVersion = MGA_PATCHLEVEL;
-   pDRIInfo->frameBufferPhysicalAddress = pMga->FbAddress;
+   pDRIInfo->frameBufferPhysicalAddress = (void *) pMga->FbAddress;
    pDRIInfo->frameBufferSize = pMga->FbMapSize;
    pDRIInfo->frameBufferStride = pScrn->displayWidth*(pScrn->bitsPerPixel/8);
    pDRIInfo->ddxDrawableTableEntry = MGA_MAX_DRAWABLES;
 
-   pDRIInfo->wrap.BlockHandler = MGABlockHandler;
-   pDRIInfo->wrap.WakeupHandler = MGAWakeupHandler;
    pDRIInfo->wrap.ValidateTree = NULL;
    pDRIInfo->wrap.PostValidateTree = NULL;
 
@@ -1118,20 +1045,8 @@ Bool MGADRIScreenInit( ScreenPtr pScreen )
       pDRIInfo->SwapContext = MGADRISwapContext;
    }
 
-   switch( pScrn->bitsPerPixel ) {
-   case 8:
-       pDRIInfo->InitBuffers = Mga8DRIInitBuffers;
-       pDRIInfo->MoveBuffers = Mga8DRIMoveBuffers;
-   case 16:
-       pDRIInfo->InitBuffers = Mga16DRIInitBuffers;
-       pDRIInfo->MoveBuffers = Mga16DRIMoveBuffers;
-   case 24:
-       pDRIInfo->InitBuffers = Mga24DRIInitBuffers;
-       pDRIInfo->MoveBuffers = Mga24DRIMoveBuffers;
-   case 32:
-       pDRIInfo->InitBuffers = Mga32DRIInitBuffers;
-       pDRIInfo->MoveBuffers = Mga32DRIMoveBuffers;
-   }
+   pDRIInfo->InitBuffers = mgaDRIInitBuffers;
+   pDRIInfo->MoveBuffers = mgaDRIMoveBuffers;
 
    pDRIInfo->bufferRequests = DRI_ALL_WINDOWS;
 
@@ -1258,12 +1173,14 @@ Bool MGADRIFinishScreenInit( ScreenPtr pScreen )
    ScrnInfoPtr pScrn = xf86Screens[pScreen->myNum];
    MGAPtr pMga = MGAPTR(pScrn);
    MGADRIServerPrivatePtr pMGADRIServer = pMga->DRIServerInfo;
-   MGADRIPtr pMGADRI = (MGADRIPtr)pMga->pDRIInfo->devPrivate;
+   MGADRIPtr pMGADRI;
    int i;
 
    if ( !pMga->pDRIInfo )
       return FALSE;
 
+   pMGADRI = (MGADRIPtr)pMga->pDRIInfo->devPrivate;
+
    pMga->pDRIInfo->driverSwapMethod = DRI_HIDE_X_CONTEXT;
 
    /* NOTE: DRIFinishScreenInit must be called before *DRIKernelInit
